@@ -26,6 +26,7 @@ from subprocess import Popen
 from os import path, getenv
 from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
 from uuid import uuid4
+from contextlib import suppress
 
 disable_warnings()
 
@@ -142,7 +143,7 @@ class QHTTPSServer():
                 headers = {}
                 client_ip = ""
 
-                try:
+                with suppress(Exception):
                     def check_bytes(string):
                         if isinstance(string, bytes):
                             return string.decode()
@@ -153,18 +154,14 @@ class QHTTPSServer():
                         headers.update({check_bytes(item): ','.join(map(check_bytes, value))})
                     headers.update({'method': check_bytes(request.method)})
                     headers.update({'uri': check_bytes(request.uri)})
-                except BaseException:
-                    pass
 
                 if 'fix_get_client_ip' in _q_s.options:
-                    try:
+                    with suppress(Exception):
                         raw_headers = dict(request.requestHeaders.getAllRawHeaders())
                         if b'X-Forwarded-For':
                             client_ip = check_bytes(raw_headers[b'X-Forwarded-For'][0])
                         elif b'X-Real-IP':
                             client_ip = check_bytes(raw_headers[b'X-Real-IP'][0])
-                    except BaseException:
-                        pass
 
                 if client_ip == "":
                     client_ip = request.getClientAddress().host
@@ -249,7 +246,7 @@ class QHTTPSServer():
         return ret
 
     def test_server(self, ip=None, port=None, username=None, password=None):
-        try:
+        with suppress(Exception):
             from requests import get, post
             _ip = ip or self.ip
             _port = port or self.port
@@ -257,8 +254,6 @@ class QHTTPSServer():
             _password = password or self.password
             get('https://{}:{}'.format(_ip, _port), verify=False)
             post('https://{}:{}'.format(_ip, _port), data={'username': (None, _username), 'password': (None, _password)}, verify=False)
-        except BaseException:
-            pass
 
 
 if __name__ == '__main__':
